@@ -3,17 +3,37 @@
 # Author : Merwin M.M
 ########################################################################
 
+
 import socket
 import os
 import sys
-import rsa
 import time
-import requests as r
 import hashlib
-from rich import print
-from rich.table import Table
-from rich.progress import track
 
+try:
+    import rsa
+    import requests as r
+    from rich import print
+    from rich.table import Table
+    from rich.progress import track
+except:
+    os.system("pip install rsa requests rich")
+try:
+    import rsa
+    import requests as r
+    from rich import print
+    from rich.table import Table
+    from rich.progress import track
+except:
+    os.system("pip3 install rsa requests rich")
+try:
+    import rsa
+    import requests as r
+    from rich import print
+    from rich.table import Table
+    from rich.progress import track
+except:
+    print("\n\n Error related to the install of the requirements... Try to install rsa , requests and rich.. Then Run..")
 
 
 table_commands = Table(title="Commands")
